Crate kcr_rds_services_k8s_aws

Crate kcr_rds_services_k8s_aws 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the rds.services.k8s.aws group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

rds.services.k8s.aws/v1alpha1

  • DBClusterParameterGroup
  • DBCluster
  • DBInstance
  • DBParameterGroup
  • DBProxy
  • DBSubnetGroup
  • GlobalCluster

Modules

v1alpha1